@@ -41,21 +41,21 @@ b),u=Math.sin(d),k=Math.cos(d),d=JM.Util.vectorAngleRadians(b,c),m=Math.sin(d),d
 1E-150)});n("JM.FF");c$=r(function(){this.elemNo=0;this.smartsCode=this.descr=null;this.fcadj=this.formalCharge=this.hType=this.mmType=0;this.pilp=this.arom=this.sbmb=!1;this.val=this.mltb=0;q(this,arguments)},JM.FF,"AtomType");w(c$,function(a,b,c,e,f,g,h){this.elemNo=a;this.mmType=b;this.hType=c;this.formalCharge=e;this.val=f;this.descr=g;this.smartsCode=h},"~N,~N,~N,~N,~N,~S,~S");n("JM.FF");p(null,"JM.FF.ForceField","java.lang.Float JU.PT JM.Util JU.Logger JV.FileManager $.Viewer".split(" "),function(){c$=
 r(function(){this.calc=this.name=null;this.stepMax=this.currentStep=this.dE=this.e0=this.criterion=0;this.coordSaved=null;this.minBondCount=this.minAtomCount=0;this.minimizer=this.bsFixed=this.minPositions=this.minTorsions=this.minAngles=this.minBonds=this.minAtoms=null;q(this,arguments)},JM.FF,"ForceField");d(c$,"setModelFields",function(){this.minAtoms=this.minimizer.minAtoms;this.minBonds=this.minimizer.minBonds;this.minAngles=this.minimizer.minAngles;this.minTorsions=this.minimizer.minTorsions;
 this.bsFixed=this.minimizer.bsMinFixed;this.minAtomCount=this.minAtoms.length;this.minBondCount=this.minBonds.length});d(c$,"setConstraints",function(a){this.bsFixed=a.bsMinFixed;this.calc.setConstraints(a.constraints);this.coordSaved=null},"JM.Minimizer");d(c$,"steepestDescentInitialize",function(a,b){this.stepMax=a;this.criterion=b/this.toUserUnits(1);this.currentStep=0;this.clearForces();this.calc.setLoggingEnabled(!0);this.calc.setLoggingEnabled(0==a||JU.Logger.isActiveLevel(6));var c=this.name+
-" "+this.calc.getDebugHeader(-1)+"Jmol Minimization Version "+JV.Viewer.getJmolVersion()+"\n";this.calc.appendLogData(c);JU.Logger.info(c);this.calc.getConstraintList();this.calc.loggingEnabled&&this.calc.appendLogData(this.calc.getAtomList("S T E E P E S T   D E S C E N T"));this.dE=0;this.calc.setPreliminary(0<a);this.e0=this.energyFull(!1,!1);c=JU.PT.sprintf(" Initial "+this.name+" E = %10.3f "+this.minimizer.units+" criterion = %8.6f max steps = "+a,"ff",k(-1,[Float.$valueOf(this.toUserUnits(this.e0)),
+" "+this.calc.getDebugHeader(-1)+"Jmol Minimization Version "+JV.Viewer.getJmolVersion()+"\n";this.calc.appendLogData(c);JU.Logger.info(c);this.calc.getConstraintList();this.calc.loggingEnabled&&this.calc.appendLogData(this.calc.getAtomList("S T E E P E S T   D E S C E N T"));this.dE=0;this.calc.setPreliminary(0<a);this.e0=this.energyFull(!1,!1);c=JU.PT.sprintf(" Initial "+this.name+" E = %10.3f "+this.minimizer.units+"/mol criterion = %8.6f max steps = "+a,"ff",k(-1,[Float.$valueOf(this.toUserUnits(this.e0)),
 Float.$valueOf(this.toUserUnits(b))]));this.minimizer.report(c,!1);this.calc.appendLogData(c)},"~N,~N");d(c$,"clearForces",function(){for(var a=0;a<this.minAtomCount;a++)this.minAtoms[a].force[0]=this.minAtoms[a].force[1]=this.minAtoms[a].force[2]=0});d(c$,"steepestDescentTakeNSteps",function(a){if(0==this.stepMax)return!1;for(var b=!0,c=1;c<=a;c++){this.currentStep++;this.calc.setSilent(!0);for(var e=0;e<this.minAtomCount;e++)(null==this.bsFixed||!this.bsFixed.get(e))&&this.setForcesUsingNumericalDerivative(this.minAtoms[e],
-1);this.linearSearch();this.calc.setSilent(!1);this.calc.loggingEnabled&&this.calc.appendLogData(this.calc.getAtomList("S T E P    "+this.currentStep));e=this.energyFull(!1,!1);this.dE=e-this.e0;var f=JM.Util.isNear3(e,this.e0,this.criterion);if(f||0==this.currentStep%10||this.stepMax<=this.currentStep){var g=JU.PT.sprintf(this.name+" Step %-4d E = %10.6f    dE = %8.6f ","Fi",k(-1,[y(-1,[e,this.dE,this.criterion]),Integer.$valueOf(this.currentStep)]));this.minimizer.report(g,!1);this.calc.appendLogData(g)}this.e0=
-e;if(f||this.stepMax<=this.currentStep)return this.calc.loggingEnabled&&this.calc.appendLogData(this.calc.getAtomList("F I N A L  G E O M E T R Y")),f&&(g=JU.PT.formatStringF("\n    "+this.name+" STEEPEST DESCENT HAS CONVERGED: E = %8.5f "+this.minimizer.units+" after "+this.currentStep+" steps","f",this.toUserUnits(e)),this.calc.appendLogData(g),this.minimizer.report(g,!0),JU.Logger.info(g)),!1;b&&2<=this.getNormalizedDE()&&(this.calc.setPreliminary(b=!1),this.e0=this.energyFull(!1,!1))}return!0},
-"~N");d(c$,"getEnergies",function(a,b){if(0!=(a&1))return this.energyFull(b,!0);var c=0;0!=(a&2)&&(c+=this.energyBond(b));0!=(a&4)&&(c+=this.energyAngle(b));0!=(a&8)&&(c+=this.energyStretchBend(b));0!=(a&32)&&(c+=this.energyOOP(b));0!=(a&16)&&(c+=this.energyTorsion(b));0!=(a&64)&&(c+=this.energyVDW(b));0!=(a&128)&&(c+=this.energyES(b));return c},"~N,~B");d(c$,"setForcesUsingNumericalDerivative",function(a,b){a.force[0]=-this.getDE(a,b,0,1E-5);a.force[1]=-this.getDE(a,b,1,1E-5);a.force[2]=-this.getDE(a,
-b,2,1E-5)},"JM.MinAtom,~N");d(c$,"getDE",function(a,b,c,e){a.coord[c]+=e;b=this.getEnergies(b,!1);a.coord[c]-=e;return(b-this.e0)/e},"JM.MinAtom,~N,~N,~N");d(c$,"energyFull",function(a,b){var c;a&&this.clearForces();c=this.energyBond(a)+this.energyAngle(a)+this.energyTorsion(a)+this.energyStretchBend(a)+this.energyOOP(a)+this.energyVDW(a)+this.energyES(a);!b&&this.calc.loggingEnabled&&this.calc.appendLogData(JU.PT.sprintf("\nTOTAL %s ENERGY = %8.3f %s/mol\n","sfs",k(-1,[this.name,Float.$valueOf(this.toUserUnits(c)),
-this.minimizer.units])));return c},"~B,~B");d(c$,"energyStretchBend",function(a){return this.calc.energyStretchBend(a)},"~B");d(c$,"energyBond",function(a){return this.calc.energyBond(a)},"~B");d(c$,"energyAngle",function(a){return this.calc.energyAngle(a)},"~B");d(c$,"energyTorsion",function(a){return this.calc.energyTorsion(a)},"~B");d(c$,"energyOOP",function(a){return this.calc.energyOOP(a)},"~B");d(c$,"energyVDW",function(a){return this.calc.energyVDW(a)},"~B");d(c$,"energyES",function(a){return this.calc.energyES(a)},
-"~B");d(c$,"linearSearch",function(){for(var a=0.23,b=this.energyFull(!1,!0),c=0;10>c;c++){this.saveCoordinates();for(var e=0;e<this.minAtomCount;++e)if(null==this.bsFixed||!this.bsFixed.get(e)){var f=this.minAtoms[e].force,g=this.minAtoms[e].coord,h=f[0]*f[0]+f[1]*f[1]+f[2]*f[2];h>0.09/a/a&&(h=0.3/Math.sqrt(h)/a,f[0]*=h,f[1]*=h,f[2]*=h);for(h=0;3>h;++h)if(JM.Util.isFinite(f[h])){var d=f[h]*a;g[h]=0.3<d?g[h]+0.3:-0.3>d?g[h]-0.3:g[h]+d}}e=this.energyFull(!1,!0);if(JM.Util.isNear3(e,b,0.001))break;
-e>b?(a*=0.1,this.restoreCoordinates()):e<b&&(b=e,a*=2.15,1<a&&(a=1))}});d(c$,"saveCoordinates",function(){null==this.coordSaved&&(this.coordSaved=s(this.minAtomCount,3,0));for(var a=0;a<this.minAtomCount;a++)for(var b=0;3>b;b++)this.coordSaved[a][b]=this.minAtoms[a].coord[b]});d(c$,"restoreCoordinates",function(){for(var a=0;a<this.minAtomCount;a++)for(var b=0;3>b;b++)this.minAtoms[a].coord[b]=this.coordSaved[a][b]});d(c$,"detectExplosion",function(){for(var a=0;a<this.minAtomCount;a++)for(var b=
-this.minAtoms[a],c=0;3>c;c++)if(!JM.Util.isFinite(b.coord[c]))return!0;for(a=0;a<this.minBondCount;a++)if(b=this.minBonds[a],900<JM.Util.distance2(this.minAtoms[b.data[0]].coord,this.minAtoms[b.data[1]].coord))return!0;return!1});d(c$,"getCurrentStep",function(){return this.currentStep});d(c$,"getEnergy",function(){return this.e0});d(c$,"getAtomList",function(a){return this.calc.getAtomList(a)},"~S");d(c$,"getEnergyDiff",function(){return this.dE});d(c$,"getLogData",function(){return this.calc.getLogData()});
-d(c$,"getNormalizedDE",function(){return Math.abs(this.dE/this.criterion)});d(c$,"toUserUnits",function(a){return this.toUnits(a,this.calc.getUnits())},"~N");d(c$,"toUnits",function(a,b){return b.equalsIgnoreCase(this.minimizer.units)?a:a*(this.minimizer.units.equals("kJ")?4.1868:0.23884589662749595)},"~N,~S");d(c$,"log",function(a){this.calc.appendLogData(a)},"~S");d(c$,"getBufferedReader",function(a){return JV.FileManager.getBufferedReaderForResource(this.minimizer.vwr,this,"JM/FF/","data/"+a)},
-"~S");v(c$,"ENERGY",1,"EBOND",2,"EANGLE",4,"ESTRBND",8,"ETORSION",16,"EOOP",32,"EVDW",64,"EELECTROSTATIC",128,"ABI_IJ",3,"ABI_JK",4,"TBI_AB",4,"TBI_BC",5,"TBI_CD",6,"R3",0,"R4",1,"R5",2,"Raromatic",3)});n("JM.FF");p(["JM.FF.ForceField"],"JM.FF.ForceFieldMMFF","java.lang.Float java.util.Hashtable JU.AU $.BS $.Lst $.PT JM.MinAtom $.MinObject JM.FF.AtomType $.CalculationsMMFF JU.BSUtil $.Elements $.Escape $.Logger JV.JmolAsyncException".split(" "),function(){c$=r(function(){this.typeData=this.line=this.vRings=
-this.rawMMFF94Charges=this.rawBondTypes=this.rawAtomTypes=null;q(this,arguments)},JM.FF,"ForceFieldMMFF",JM.FF.ForceField);F(c$,function(){this.typeData=m(4,0)});d(c$,"getAtomTypeDescriptions",function(){return JM.FF.ForceFieldMMFF.getAtomTypeDescs(this.rawAtomTypes)});d(c$,"getPartialCharges",function(){return this.rawMMFF94Charges});w(c$,function(a){A(this,JM.FF.ForceFieldMMFF,[]);this.minimizer=a;this.name="MMFF";this.getParameters()},"JM.Minimizer");l(c$,"clear",function(){});l(c$,"setModel",
-function(){var a=this.minimizer;if(!this.setArrays(a.atoms,a.bsAtoms,a.bonds,a.rawBondCount,!1,!1))return!1;this.setModelFields();if(!this.fixTypes())return!1;this.calc=new JM.FF.CalculationsMMFF(this,JM.FF.ForceFieldMMFF.ffParams,this.minAtoms,this.minBonds,this.minAngles,this.minTorsions,this.minPositions,this.minimizer.constraints);this.calc.setLoggingEnabled(!0);return this.calc.setupCalculations()},"JU.BS,~N");d(c$,"setArrays",function(a,b,c,e,f,g){var h=this.minimizer;this.vRings=JU.AU.createArrayOfArrayList(4);
-this.rawAtomTypes=JM.FF.ForceFieldMMFF.setAtomTypes(a,b,h.vwr.getSmilesMatcher(),this.vRings,g);if(null==this.rawAtomTypes)return!1;this.rawBondTypes=this.setBondTypes(c,e,b);this.rawMMFF94Charges=JM.FF.ForceFieldMMFF.calculatePartialCharges(c,this.rawBondTypes,a,this.rawAtomTypes,b,f);return!0},"~A,JU.BS,~A,~N,~B,~B");d(c$,"getParameters",function(){if(null==JM.FF.ForceFieldMMFF.ffParams){this.getAtomTypes();var a=new java.util.Hashtable;JU.Logger.debugging&&JU.Logger.debug("reading data from mmff94.par.txt");
+1);this.linearSearch();this.calc.setSilent(!1);this.calc.loggingEnabled&&this.calc.appendLogData(this.calc.getAtomList("S T E P    "+this.currentStep));e=this.energyFull(!1,!1);this.dE=e-this.e0;var f=JM.Util.isNear3(e,this.e0,this.criterion);if(f||0==this.currentStep%10||this.stepMax<=this.currentStep){var g=JU.PT.sprintf(this.name+" Step %-4d E = %10.6f    dE = %8.6f ","Fi",k(-1,[y(-1,[this.toUserUnits(e),this.toUserUnits(this.dE)]),Integer.$valueOf(this.currentStep)]));this.minimizer.report(g,
+!1);this.calc.appendLogData(g)}this.e0=e;if(f||this.stepMax<=this.currentStep)return this.calc.loggingEnabled&&this.calc.appendLogData(this.calc.getAtomList("F I N A L  G E O M E T R Y")),f&&(g=JU.PT.formatStringF("\n    "+this.name+" STEEPEST DESCENT HAS CONVERGED: E = %8.5f "+this.minimizer.units+"/mol after "+this.currentStep+" steps","f",this.toUserUnits(e)),this.calc.appendLogData(g),this.minimizer.report(g,!0),JU.Logger.info(g)),!1;b&&2<=this.getNormalizedDE()&&(this.calc.setPreliminary(b=!1),
+this.e0=this.energyFull(!1,!1))}return!0},"~N");d(c$,"getEnergies",function(a,b){if(0!=(a&1))return this.energyFull(b,!0);var c=0;0!=(a&2)&&(c+=this.energyBond(b));0!=(a&4)&&(c+=this.energyAngle(b));0!=(a&8)&&(c+=this.energyStretchBend(b));0!=(a&32)&&(c+=this.energyOOP(b));0!=(a&16)&&(c+=this.energyTorsion(b));0!=(a&64)&&(c+=this.energyVDW(b));0!=(a&128)&&(c+=this.energyES(b));return c},"~N,~B");d(c$,"setForcesUsingNumericalDerivative",function(a,b){a.force[0]=-this.getDE(a,b,0,1E-5);a.force[1]=-this.getDE(a,
+b,1,1E-5);a.force[2]=-this.getDE(a,b,2,1E-5)},"JM.MinAtom,~N");d(c$,"getDE",function(a,b,c,e){a.coord[c]+=e;b=this.getEnergies(b,!1);a.coord[c]-=e;return(b-this.e0)/e},"JM.MinAtom,~N,~N,~N");d(c$,"energyFull",function(a,b){var c;a&&this.clearForces();c=this.energyBond(a)+this.energyAngle(a)+this.energyTorsion(a)+this.energyStretchBend(a)+this.energyOOP(a)+this.energyVDW(a)+this.energyES(a);!b&&this.calc.loggingEnabled&&this.calc.appendLogData(JU.PT.sprintf("\nTOTAL %s ENERGY = %8.3f %s/mol\n","sfs",
+k(-1,[this.name,Float.$valueOf(this.toUserUnits(c)),this.minimizer.units])));return c},"~B,~B");d(c$,"energyStretchBend",function(a){return this.calc.energyStretchBend(a)},"~B");d(c$,"energyBond",function(a){return this.calc.energyBond(a)},"~B");d(c$,"energyAngle",function(a){return this.calc.energyAngle(a)},"~B");d(c$,"energyTorsion",function(a){return this.calc.energyTorsion(a)},"~B");d(c$,"energyOOP",function(a){return this.calc.energyOOP(a)},"~B");d(c$,"energyVDW",function(a){return this.calc.energyVDW(a)},
+"~B");d(c$,"energyES",function(a){return this.calc.energyES(a)},"~B");d(c$,"linearSearch",function(){for(var a=0.23,b=this.energyFull(!1,!0),c=0;10>c;c++){this.saveCoordinates();for(var e=0;e<this.minAtomCount;++e)if(null==this.bsFixed||!this.bsFixed.get(e)){var f=this.minAtoms[e].force,g=this.minAtoms[e].coord,h=f[0]*f[0]+f[1]*f[1]+f[2]*f[2];h>0.09/a/a&&(h=0.3/Math.sqrt(h)/a,f[0]*=h,f[1]*=h,f[2]*=h);for(h=0;3>h;++h)if(JM.Util.isFinite(f[h])){var d=f[h]*a;g[h]=0.3<d?g[h]+0.3:-0.3>d?g[h]-0.3:g[h]+
+d}}e=this.energyFull(!1,!0);if(JM.Util.isNear3(e,b,0.001))break;e>b?(a*=0.1,this.restoreCoordinates()):e<b&&(b=e,a*=2.15,1<a&&(a=1))}});d(c$,"saveCoordinates",function(){null==this.coordSaved&&(this.coordSaved=s(this.minAtomCount,3,0));for(var a=0;a<this.minAtomCount;a++)for(var b=0;3>b;b++)this.coordSaved[a][b]=this.minAtoms[a].coord[b]});d(c$,"restoreCoordinates",function(){for(var a=0;a<this.minAtomCount;a++)for(var b=0;3>b;b++)this.minAtoms[a].coord[b]=this.coordSaved[a][b]});d(c$,"detectExplosion",
+function(){for(var a=0;a<this.minAtomCount;a++)for(var b=this.minAtoms[a],c=0;3>c;c++)if(!JM.Util.isFinite(b.coord[c]))return!0;for(a=0;a<this.minBondCount;a++)if(b=this.minBonds[a],900<JM.Util.distance2(this.minAtoms[b.data[0]].coord,this.minAtoms[b.data[1]].coord))return!0;return!1});d(c$,"getCurrentStep",function(){return this.currentStep});d(c$,"getEnergy",function(){return this.e0});d(c$,"getAtomList",function(a){return this.calc.getAtomList(a)},"~S");d(c$,"getEnergyDiff",function(){return this.dE});
+d(c$,"getLogData",function(){return this.calc.getLogData()});d(c$,"getNormalizedDE",function(){return Math.abs(this.dE/this.criterion)});d(c$,"toUserUnits",function(a){return this.toUnits(a,this.calc.getUnits())},"~N");d(c$,"toUnits",function(a,b){return b.equalsIgnoreCase(this.minimizer.units)?a:a*(this.minimizer.units.equals("kJ")?4.1868:0.23884589662749595)},"~N,~S");d(c$,"log",function(a){this.calc.appendLogData(a)},"~S");d(c$,"getBufferedReader",function(a){return JV.FileManager.getBufferedReaderForResource(this.minimizer.vwr,
+this,"JM/FF/","data/"+a)},"~S");v(c$,"ENERGY",1,"EBOND",2,"EANGLE",4,"ESTRBND",8,"ETORSION",16,"EOOP",32,"EVDW",64,"EELECTROSTATIC",128,"ABI_IJ",3,"ABI_JK",4,"TBI_AB",4,"TBI_BC",5,"TBI_CD",6,"R3",0,"R4",1,"R5",2,"Raromatic",3)});n("JM.FF");p(["JM.FF.ForceField"],"JM.FF.ForceFieldMMFF","java.lang.Float java.util.Hashtable JU.AU $.BS $.Lst $.PT JM.MinAtom $.MinObject JM.FF.AtomType $.CalculationsMMFF JU.BSUtil $.Elements $.Escape $.Logger JV.JmolAsyncException".split(" "),function(){c$=r(function(){this.typeData=
+this.line=this.vRings=this.rawMMFF94Charges=this.rawBondTypes=this.rawAtomTypes=null;q(this,arguments)},JM.FF,"ForceFieldMMFF",JM.FF.ForceField);F(c$,function(){this.typeData=m(4,0)});d(c$,"getAtomTypeDescriptions",function(){return JM.FF.ForceFieldMMFF.getAtomTypeDescs(this.rawAtomTypes)});d(c$,"getPartialCharges",function(){return this.rawMMFF94Charges});w(c$,function(a){A(this,JM.FF.ForceFieldMMFF,[]);this.minimizer=a;this.name="MMFF";this.getParameters()},"JM.Minimizer");l(c$,"clear",function(){});
+l(c$,"setModel",function(){var a=this.minimizer;if(!this.setArrays(a.atoms,a.bsAtoms,a.bonds,a.rawBondCount,!1,!1))return!1;this.setModelFields();if(!this.fixTypes())return!1;this.calc=new JM.FF.CalculationsMMFF(this,JM.FF.ForceFieldMMFF.ffParams,this.minAtoms,this.minBonds,this.minAngles,this.minTorsions,this.minPositions,this.minimizer.constraints);this.calc.setLoggingEnabled(!0);return this.calc.setupCalculations()},"JU.BS,~N");d(c$,"setArrays",function(a,b,c,e,f,g){var h=this.minimizer;this.vRings=
+JU.AU.createArrayOfArrayList(4);this.rawAtomTypes=JM.FF.ForceFieldMMFF.setAtomTypes(a,b,h.vwr.getSmilesMatcher(),this.vRings,g);if(null==this.rawAtomTypes)return!1;this.rawBondTypes=this.setBondTypes(c,e,b);this.rawMMFF94Charges=JM.FF.ForceFieldMMFF.calculatePartialCharges(c,this.rawBondTypes,a,this.rawAtomTypes,b,f);return!0},"~A,JU.BS,~A,~N,~B,~B");d(c$,"getParameters",function(){if(null==JM.FF.ForceFieldMMFF.ffParams){this.getAtomTypes();var a=new java.util.Hashtable;JU.Logger.debugging&&JU.Logger.debug("reading data from mmff94.par.txt");
 var b=null,c=null;try{for(var b=this.getBufferedReader("mmff94.par.txt"),e=0,f=0;;){for(;0>(e=(c=b.readLine()).indexOf(".PAR")););if(1>(f=JM.FF.ForceFieldMMFF.types[G("END.BCI.CHG.ANG.NDK.OND.OOP.TBN.FSB.TOR.VDW.".indexOf(c.substring(e-3,e+1))/4)]))break;this.readParams(b,f,a)}b.close()}catch(g){if(z(g,JV.JmolAsyncException))throw new JV.JmolAsyncException(g.getFileName());if(z(g,Exception))System.err.println("Exception "+g.toString()+" in getResource mmff94.par.txt line="+c);else throw g;}finally{try{b.close()}catch(h){if(!z(h,
 Exception))throw h;}}JM.FF.ForceFieldMMFF.ffParams=a}});d(c$,"readParams",function(a,b,c){var e=null,f=0,g=127,h=127,d=127,u=0;switch(b){case 34:d=124;break;case 21:d=125;break;case 546:d=123;u=0;break;case 13:u=6;break;case 1:u=0;break;case 37:d=126;u=0;break;case 17:d=122,u=0}for(;!a.readLine().startsWith("*"););for(;(this.line=a.readLine()).startsWith("*"););do{switch(b){case 17:if(" "!=this.line.charAt(5))continue;break;case 34:if("4"==this.line.charAt(0))continue;case 5:case 3:case 21:case 9:u=
 this.line.charCodeAt(0)-48}switch(b){case 13:case 9:d=this.ival(18,20);case 5:case 21:case 37:h=this.ival(13,15);case 546:case 3:case 34:g=this.ival(8,10);case 1:case 17:f=this.ival(3,5)}switch(b){case 546:e=s(-1,[this.dval(19,25),this.dval(13,18)]);break;case 3:e=s(-1,[this.dval(14,20),this.dval(25,31)]);break;case 5:case 21:e=s(-1,[this.dval(19,25),this.dval(28,35)]);break;case 34:e=Float.$valueOf(this.fval(10,20));break;case 13:e=s(-1,[this.dval(24,30)]);break;case 1:e=Float.$valueOf(this.fval(5,
