@@ -975,8 +975,12 @@ var isMF = !isList && sFind.equalsIgnoreCase ("MF");
 var isCF = !isList && sFind.equalsIgnoreCase ("CELLFORMULA");
 var argLast = (args.length > 0 ? args[args.length - 1] : JS.SV.vF);
 var isON = !isList && (argLast.tok == 1073742335);
+var isInchi = !isList && sFind.equalsIgnoreCase ("INCHI");
 try {
-if (isChemical) {
+if (isInchi) {
+if (x1.tok != 10) return false;
+return mp.addXStr (this.vwr.getInchi (x1.value, flags));
+}if (isChemical) {
 var bsAtoms = (x1.tok == 10 ? x1.value : null);
 var data = (bsAtoms == null ? JS.SV.sValue (x1) : this.vwr.getOpenSmiles (bsAtoms));
 data = (data.length == 0 ? "" : this.vwr.getChemicalInfo (data, flags.toLowerCase (), bsAtoms)).trim ();
@@ -1514,25 +1518,22 @@ throw e;
 }, "JS.ScriptMathProcessor,~A,~B");
 Clazz_defineMethod (c$, "evaluateMath", 
  function (mp, args, tok) {
-if (tok == 134218760) {
-if (args.length == 1 && args[0].tok == 4) return mp.addXStr (( new java.util.Date ()) + "\t" + JS.SV.sValue (args[0]));
-return mp.addXInt ((System.currentTimeMillis () & 0x7FFFFFFF) - (args.length == 0 ? 0 : args[0].asInt ()));
-}if (args.length != 1) return false;
-if (tok == 134218250) {
-if (args[0].tok == 2) return mp.addXInt (Math.abs (args[0].asInt ()));
-return mp.addXFloat (Math.abs (args[0].asFloat ()));
-}var x = JS.SV.fValue (args[0]);
+var x = JS.SV.fValue (args[0]);
 switch (tok) {
-case 134218242:
-return mp.addXFloat ((Math.acos (x) * 180 / 3.141592653589793));
-case 134218245:
-return mp.addXFloat (Math.cos (x * 3.141592653589793 / 180));
-case 134218244:
-return mp.addXFloat (Math.sin (x * 3.141592653589793 / 180));
 case 134218246:
-return mp.addXFloat (Math.sqrt (x));
+x = Math.sqrt (x);
+break;
+case 134218244:
+x = Math.sin (x * 3.141592653589793 / 180);
+break;
+case 134218245:
+x = Math.cos (x * 3.141592653589793 / 180);
+break;
+case 134218242:
+x = Math.acos (x) * 180 / 3.141592653589793;
+break;
 }
-return false;
+return mp.addXFloat (x);
 }, "JS.ScriptMathProcessor,~A,~N");
 Clazz_defineMethod (c$, "evaluateMeasure", 
  function (mp, args, tok) {
